@rem = ' This is a perl script for NT and UNIX.
@echo off
goto endofperl
@rem ';
# -*- tab-width: 4 -*-

#---------------------------------------------------------------------------+
# Licensed Materials - Property of IBM
# Rational ClearCase
# Copyright IBM Corp. 2003, 2005. All Rights Reserved
# US Government Users Restricted Rights -
# Use, duplication or disclosure restricted by GSA ADP Schedule Contract
# with IBM Corp.
#---------------------------------------------------------------------------+

###########################################################################
# syncmgr_dbscrubber.bat
# usage: syncmgr_dbscrubber.bat - run with "-help" for detailed usage.
#
# This script is intended to be run periodically by the ClearCase
# Job Scheduler to scrub old entries from the sync manager's internal
# database.
###########################################################################

use strict;
use Getopt::Long;

use ClearCase::CurrentVersion;
sub dbgprint;  # predeclare, routine is in require file
sub qprint;    # predeclare

my $thisscript = $0;
if ($thisscript =~ m/(.*)(\.bat)$/) {
    $thisscript = $1;
}

my $pkg_name = 'syncmgr_dbscrubber';
$CFG::verbose = ($ENV{TRACE_SUBSYS} && ($ENV{TRACE_SUBSYS} =~ m/$pkg_name/));
# force debugging msgs by uncommenting the following and setting to 1.....
#$CFG::verbose = 1;

$CFG::quietmode = 0;

# if 'verbose' mode is on, force the debug msgs to also print to STDERR by
# uncommenting this line (forces debug msgs to appear in the log file,
# useful if you're having problems with a receipt handler).
#$CFG::stderr_msgs = 1;

use Config;
my $arch = $^O ? $^O : $main::Config{archname};
$CFG::NT = (($arch =~ /^MSWin32/) || ($arch eq 'i386-win32')) ? 1 : 0;
$CFG::UNIX = ($CFG::NT ? 0 : 1);

# CLEARCASEHOME e.v. should always be set on NT when called by ccperlpp.pl,
# so exit if it's not set. On UNIX, ClearCase::CurrentVersion::SetProductHomeEV()
# assumes /opt/rational/clearcase if user hasn't explicitly set CLEARCASEHOME 
# (or deprecated ATRIAHOME).
my $scrub;

if ($CFG::UNIX) {
    my $producthome = &ClearCase::CurrentVersion::SetProductHomeEV;
    chdir $producthome;
    push(@INC, "$producthome/config/scheduler/tasks");
    $scrub = "$producthome/etc/syncmgr_scrubber";
} else {
    my $producthome = $ENV{CLEARCASEHOME} or 
                      die "CLEARCASEHOME env. variable not set\n";
    chdir $producthome;
    push(@INC, "$producthome\\config\\scheduler\\tasks");
    $thisscript = $pkg_name;
    $scrub = qq/"$producthome\\bin\\syncmgr_scrubber"/;
}
$CFG::including_script = $thisscript;

# set script version to test for mismatch against the syncmgr_common.pl version.
$CFG::MS_script_version = "7.0.0.0_syncmgr";

require 'syncmgr_common.pl';
require 5.8.6;

if (!$CFG::MScommon_version) {
    $CFG::MScommon_version = "(unknown older version)";
}

# check versions - syncmgr_common.pl should set $CFG::MScommon_version; 
# if not set or unequal, indicates that an older/newer version is being
# included improperly.

if ($CFG::MScommon_version ne $CFG::MS_script_version) {
    die "Version mismatch between require file 'syncmgr_common.pl'" .
        " (version: ${CFG::MScommon_version}) and \n" .
        "the MultiSite script which includes it, 'syncmgr_dbscrubber.bat'" .
        " (version: ${CFG::MS_script_version}).\n" . 
        "Ensure that old versions of the script/require file are not in use.\n";
}

$| = 1 if $CFG::verbose;

dbgprint "running in directory: ", DoCmd($CFG::workingdir_cmd);
dbgprint "running on architecture $arch\n";

###########################################################################
# main
#

my $usage = "$thisscript [-help | -partial days -complete days]\n" .
    "    More extensive help is available by using the '-h' command-line switch.\n";

my $helpmsg = <<ENDHELP;
=========================================================================
"syncmgr_dbscrubber" is designed to be run by the ClearCase Job Scheduler
to periodically remove completed jobs from the sync manager's internal
database. This will reduce the size of the database and help to keep its
performance from degrading as the database size increases.

Data about the jobs run by the sync manager are kept in its internal database
after completion of the job to aid in problem diagnosis and to provide 
data required by the MultiSite family health, performance info, and 
synchronization info tools. The MultiSite administrator has control, via
the use of scrubbing, to choose how long this information is kept.

Two levels of scrubbing will be used. "Partial" scrubbing removes the 
portion of the job data containing information that is specific to the
particular job, such as packet pathnames that are no longer important
soon after the job has completed. A typical setting for this might be 
7 to 14 days. Jobs with a 'success' status code and a completion time older
than this number of days will have their job-specific data removed,
while retaining general information about the job useful for gathering
performance information and throughput statistics. Jobs with an abnormal
completion status will not have any of their information scrubbed
at this stage to ensure that the administrator has adequate opportunity
to analyze the information.

The second type of scrubbing is "complete" scrubbing. All job information
for jobs whose completion time is older than this many days will be removed 
from the database. To allow for gathering long term information on
MultiSite throughput, typical values for this parameter might be 60
or 90 days.

Both scrubbing age parameters must be specified.

The number of days for either "success" or "complete" scrubbing must be in
the range of 1 to 180 days, and the "success" days value must be equal to or
smaller than the "complete" value.

A job in any uncompleted state will not be scrubbed, regardless of its age.

$usage
Command line options:

    - help                      Display this help message and exit.

    - partial <number of days>  Successfully completed jobs older than
                                this number of days will be partially
                                scrubbed (job-specific data removed, but
                                performance-related data kept).

    - complete <number of days> All jobs whose completion time is more
                                than this number of days old will be
                                completely removed from the database. This
                                value must be equal to, or larger than
                                the '-partial' value.
=========================================================================
ENDHELP

# get command line options figured out...
dbgprint "ARGV: " . join(' ',@ARGV) . "\n";

# set defaults for the ages of jobs that will be scrubbed
my $partial_days = -1;
my $complete_days = -1;
my $help = 0;

my $st = GetOptions("partial=i" => \$partial_days,
                 "help!" => \$help,
                 "complete=i" => \$complete_days);

if ($help) {
    qprint "$helpmsg\n";
    exit 1;
}

if (!$st) {
    qprint "ERROR: error getting command line options.\nUsage: $usage\n";
    exit 1;
}

if ($complete_days == -1 || $partial_days == -1) {
    qprint "ERROR: both -complete and -partial must be specified.\n" .
           "Usage: $usage\n";
    exit 1;
}

dbgprint "options:\n    partial days: $partial_days\n" . 
    "    complete days: $complete_days\n";

if ($complete_days < $partial_days) {
    qprint("ERROR: 'complete' days must be greater or equal to 'partial' days.\n");
    exit 1;
}

my $date_range_msg = "ERROR: complete and partial parameters must be between" .
    " 1 and 180 days";

if ($partial_days > 180 || $partial_days < 1) {
    qprint($date_range_msg);
    exit 1;
}

if ($complete_days > 180 || $complete_days < 1) {
    qprint($date_range_msg);
    exit 1;
}

my $cmd ="$scrub -partial $partial_days -complete $complete_days\n";
print $cmd . "\n";
$st = system($cmd);


__END__
:endofperl
ccperl -S ccperlpp.pl %0.bat %*
